diff --git a/Cargo.lock b/Cargo.lock
index c55b9f97ca..b55e2aeb39 100644
--- a/Cargo.lock
+++ b/Cargo.lock
@@ -1348,12 +1348,13 @@ dependencies = [
[[package]]
name = "deno_cache_dir"
-version = "0.12.0"
+version = "0.13.0"
source = "registry+https://github.com/rust-lang/crates.io-index"
-checksum = "87900cfcd07bdbf3597bc36b77da0c0e7b6c2e65213faa2ed43d9a1ec12bd31d"
+checksum = "186a102b13b4512841f5f40784cd25822042d22954afe3b5b070d406d15eb4f2"
dependencies = [
"base32",
"deno_media_type",
+ "deno_path_util",
"indexmap",
"log",
"once_cell",
diff --git a/Cargo.toml b/Cargo.toml
index ce333c728b..b15c1241b5 100644
--- a/Cargo.toml
+++ b/Cargo.toml
@@ -110,7 +110,7 @@ console_static_text = "=0.8.1"
dashmap = "5.5.3"
data-encoding = "2.3.3"
data-url = "=0.3.0"
-deno_cache_dir = "=0.12.0"
+deno_cache_dir = "=0.13.0"
deno_package_json = { version = "=0.1.1", default-features = false }
dlopen2 = "0.6.1"
ecb = "=0.1.2"
diff --git a/cli/cache/mod.rs b/cli/cache/mod.rs
index 2296bce010..628502c506 100644
--- a/cli/cache/mod.rs
+++ b/cli/cache/mod.rs
@@ -87,10 +87,6 @@ impl deno_cache_dir::DenoCacheEnv for RealDenoCacheEnv {
std::fs::create_dir_all(path)
}
- fn remove_file(&self, path: &Path) -> std::io::Result<()> {
- std::fs::remove_file(path)
- }
-
fn modified(&self, path: &Path) -> std::io::Result
diff --git a/cli/cache/deno_dir.rs b/cli/cache/deno_dir.rs
index 88d8a31c04..7b7059c224 100644
--- a/cli/cache/deno_dir.rs
+++ b/cli/cache/deno_dir.rs
@@ -126,9 +126,9 @@ impl DenoDir {
self.root.join("registries")
}
- /// Path to the dependencies cache folder.
- pub fn deps_folder_path(&self) -> PathBuf {
- self.root.join("deps")
+ /// Path to the remote cache folder.
+ pub fn remote_folder_path(&self) -> PathBuf {
+ self.root.join("remote")
}
/// Path to the origin data cache folder.